"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Player = void 0;
const axios_1 = require("axios");
class Player {
    constructor(data) {
        this.tag = data.tag;
        this.name = data.name;
        this.nameColor = data.nameColor;
        this.icon = data.icon;
        this.trophies = data.trophies;
        this.highestTrophies = data.highestTrophies;
        this.highestPowerPlayPoints = data.highestPowerPlayPoints;
        this.expLevel = data.expLevel;
        this.expPoints = data.expPoints;
        this.isQualifiedFromChampionshipChallenge =
            data.isQualifiedFromChampionshipChallenge;
        this.trioVictories = data.trioVictories;
        this.soloVictories = data.soloVictories;
        this.duoVictories = data.duoVictories;
        this.bestRoboRumbleTime = data.bestRoboRumbleTime;
        this.brawlersCount = data.brawlers.length;
        this.club = data.club;
        this.brawlers = data.brawlers;
        this.starPowerCount = this.getStarPowerCount();
        this.gadgetCount = this.getGadgetCount();
        this.gearsCount = this.getGearCount();
    }
    getTotalWins() {
        return this.trioVictories + this.soloVictories + this.duoVictories;
    }
    getIconUrl() {
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield axios_1.default.get("https://api.brawlapi.com/v1/icons");
            if (response.status !== 200) {
                throw new Error("Error getting icons from BrawlAPI");
            }
            return response.data.player[this.icon.id].imageUrl;
        });
    }
    getColor() {
        if (this.nameColor == null)
            return "ffffff";
        return this.nameColor.slice(4);
    }
    getBrawlers() {
        return this.brawlers;
    }
    getBrawlersByTrophies() {
        return this.brawlers.sort((a, b) => {
            return b.trophies - a.trophies;
        });
    }
    getBrawlersByPower() {
        return this.brawlers.sort((a, b) => {
            return b.power - a.power;
        });
    }
    getBrawlersByRank() {
        return this.brawlers.sort((a, b) => {
            return b.rank - a.rank;
        });
    }
    getBrawlerByName(name) {
        return (this.brawlers.find((brawler) => brawler.name === name.toUpperCase()) ||
            null);
    }
    getBrawlerById(id) {
        return this.brawlers.find((brawler) => brawler.id === id) || null;
    }
    getBrawlerCount() {
        return this.brawlers.length;
    }
    getStarPowerCount() {
        return this.brawlers.reduce((acc, brawler) => {
            return acc + brawler.starPowers.length;
        }, 0);
    }
    getGadgetCount() {
        return this.brawlers.reduce((acc, brawler) => {
            return acc + brawler.gadgets.length;
        }, 0);
    }
    getGearCount() {
        return this.brawlers.reduce((acc, brawler) => {
            return acc + brawler.gears.length;
        }, 0);
    }
}
exports.Player = Player;
//# sourceMappingURL=player.js.map