"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const APIError_1 = require("./APIError");
const brawlers_1 = require("./brawlers");
const club_1 = require("./club");
const events_1 = require("./events");
const player_1 = require("./player");
const rankings_1 = require("./rankings");
const baseURL = "https://api.brawlstars.com/v1";
class request {
    constructor(client) {
        this.client = client;
    }
    getHeaders() {
        return {
            Authorization: `Bearer ${this.client.token}`,
            Accept: "application/json",
        };
    }
    getPlayer(tag) {
        return __awaiter(this, void 0, void 0, function* () {
            tag = tag.replace("#", "");
            let response = yield axios_1.default
                .get(`${baseURL}/players/%23${tag}`, {
                headers: this.getHeaders(),
            })
                .catch((error) => {
                throw new APIError_1.default(error.response, error.response.data.reason);
            });
            response.data.trioVictories = response.data["3vs3Victories"];
            return new player_1.Player(response.data);
        });
    }
    getPlayerBattleLog(tag) {
        return __awaiter(this, void 0, void 0, function* () {
            tag = tag.replace("#", "");
            let response = yield axios_1.default
                .get(`${baseURL}/players/%23${tag}/battlelog`, {
                headers: this.getHeaders(),
            })
                .catch((error) => {
                throw new APIError_1.default(error.response, error.response.data.reason);
            });
            return response.data.items;
        });
    }
    getClub(tag) {
        return __awaiter(this, void 0, void 0, function* () {
            tag = tag.replace("#", "");
            let response = yield axios_1.default
                .get(`${baseURL}/clubs/%23${tag}`, {
                headers: this.getHeaders(),
            })
                .catch((error) => {
                throw new APIError_1.default(error.response, error.response.data.reason);
            });
            return new club_1.Club(response.data);
        });
    }
    getRankings(type = "player" /* RankingType.PLAYER */, countryCode = "global" /* CountryCode.GLOBAL */, brawlerId = null) {
        return __awaiter(this, void 0, void 0, function* () {
            if (type === "club" /* RankingType.CLUB */) {
                let response = yield axios_1.default
                    .get(`${baseURL}/rankings/${countryCode}/clubs`, {
                    headers: this.getHeaders(),
                })
                    .catch((error) => {
                    throw new APIError_1.default(error.response, error.response.data.reason);
                });
                return new rankings_1.Ranking("club", response.data.items);
            }
            if (type === "brawler" /* RankingType.BRAWLER */ && brawlerId === null)
                throw new Error("Brawler ID is required for this type");
            if (type === "brawler" /* RankingType.BRAWLER */) {
                let response = yield axios_1.default
                    .get(`${baseURL}/rankings/${countryCode}/brawlers/${brawlerId}`, {
                    headers: this.getHeaders(),
                })
                    .catch((error) => {
                    throw new APIError_1.default(error.response, error.response.data.reason);
                });
                return new rankings_1.Ranking("brawler", response.data.items);
            }
            let response = yield axios_1.default
                .get(`${baseURL}/rankings/${countryCode}/players`, {
                headers: this.getHeaders(),
            })
                .catch((error) => {
                throw new APIError_1.default(error.response, error.response.data.reason);
            });
            return new rankings_1.Ranking("player", response.data.items);
        });
    }
    getBrawlers() {
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield axios_1.default
                .get(`${baseURL}/brawlers`, {
                headers: this.getHeaders(),
            })
                .catch((error) => {
                throw new APIError_1.default(error.response, error.response.data.reason);
            });
            return new brawlers_1.Brawlers(response.data);
        });
    }
    getEvents() {
        return __awaiter(this, void 0, void 0, function* () {
            let response = yield axios_1.default
                .get(`${baseURL}/events/rotation`, {
                headers: this.getHeaders(),
            })
                .catch((error) => {
                throw new APIError_1.default(error.response, error.response.data.reason);
            });
            return new events_1.Events(response.data);
        });
    }
}
exports.default = request;
//# sourceMappingURL=request.js.map